@@ -1,5 +1,6 @@
 EXTENSIONS = {
     'adoc': {'text', 'asciidoc'},
+    'ai': {'binary', 'adobe-illustrator'},
     'asciidoc': {'text', 'asciidoc'},
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
@@ -294,4 +295,5 @@ NAMES = {
     'Rakefile': EXTENSIONS['rb'],
     'setup.cfg': EXTENSIONS['ini'],
     'WORKSPACE': EXTENSIONS['bzl'],
+    'wscript': EXTENSIONS['py'],
 }
